@@ -282,10 +282,7 @@ class Client(object):
             # this will return a zip file instead of csv!
             res = self.session.get(
                 self.service_url+'download_file',
-                json={
-                    'file_tag':'DESCRIPTORS'+str(process_id),
-                    'file_ext':'.csv'
-                }
+                json={'file_tag':'DESCRIPTORS'+str(process_id)}
             )
             if output_path:
                 with open(output_path,'wb') as f:
@@ -688,6 +685,28 @@ class Client(object):
         else:
             return {'success':False,'status_code':resp.status_code}
 
+    def get_design_id(self,design_name):
+        """Get the id of a design by providing its name.
+
+        Parameters
+        ----------
+        design_name : str 
+            Name of the desired design. 
+
+        Returns
+        -------
+        response : dict 
+            Response data or error report. 
+        """
+        resp = self.session.get(
+            self.service_url+'api/get_design_id',
+            params={'design_name':design_name}
+        )
+        if resp.status_code == 200:
+            return resp.json()
+        else:
+            return {'success':False,'status_code':resp.status_code}
+
     def new_design(self,dataset_id,name,description=''):
         """Create a new design on Aionics.
 
@@ -893,6 +912,7 @@ class Client(object):
             - 'concentration_weighted' (bool): Optional, default False. Multiplies the descriptors by substance concentrations. For a column named 'substance1', the concentration data is assumed to be in a column named 'substance1_conc'.
             - 'in_solution' (bool): Optional, default False. Substances in solution get their descriptors combined additively with the descriptors of other substances in the same solution.
             - 'solution_name' (str): If in_solution, specifies which solution the substance is in.
+            - 'use_properties' (bool): Optional, default False. Includes any properties attached to the substance as descriptors for featurization. 
 
         Returns
         -------
@@ -919,6 +939,8 @@ class Client(object):
                 data[subsk+'_insoln'] = stgs['in_solution']
             if 'solution_name' in stgs:
                 data[subsk+'_solnname'] = stgs['solution_name']
+            if 'use_properties' in stgs:
+                data[subsk+'_useprops'] = stgs['use_properties']
         resp = self.session.post(
             self.service_url+'featurize', 
             json=data
@@ -1148,7 +1170,53 @@ class Client(object):
 
     # APPLY MODEL
 
-    def apply_model(self,model_id,samples,run_featurization=False,run_transformation=True):
+    def apply_models(self,model_ids,samples,run_featurization=True,run_transformation=True):
+        """Apply multiple models to one or more samples by providing model inputs.
+
+        Parameters
+        ----------
+        model_ids : list of int
+            List of integer ids of the models to be applied
+        samples : dict or pandas.DataFrame
+            Model inputs- if it is a dict, the keys are sample ids, 
+            and values are dicts of model inputs. 
+            If it is a DataFrame, the index contains sample ids,
+            and the columns are the model inputs.
+        run_featurization : bool
+            Whether or not to run featurization on the samples
+        run_transformation : bool
+            Whether or not to run transformation on the samples
+
+        Returns
+        -------
+        resp : dict
+            Dict containing model results or error reports
+        """
+        if isinstance(samples,pd.DataFrame):
+            samples = samples.to_dict(orient='index')
+        pid_resp = self.session.get(
+            self.service_url+'process_id', 
+            data = {
+                'process_tag':'APPLY_MODELS_'+uuid.uuid4().hex
+            }
+        )
+        procid = pid_resp.json()['process_id']
+        resp = self.session.post(
+            self.service_url+'api/apply_models', 
+            json = {
+                'model_ids':model_ids,
+                'process_id':procid,
+                'run_featurization':run_featurization,
+                'run_transformation':run_transformation,
+                'samples':samples
+            }
+        )
+        if resp.status_code == 200:
+            return resp.json()
+        else:
+            return {'success':False,'status_code':resp.status_code}
+            
+    def apply_model(self,model_id,samples,run_featurization=True,run_transformation=True):
         """Apply a model to one or more samples by providing model inputs.
 
         Parameters
@@ -1176,7 +1244,7 @@ class Client(object):
             self.service_url+'model_process_id', 
             json={
                 'model_id':model_id,
-                'process_tag':'RESULTS'+uuid.uuid4().hex
+                'process_tag':'APPLY_MODEL_'+uuid.uuid4().hex
             }
         )
         procid = pid_resp.json()['process_id']
@@ -1194,7 +1262,8 @@ class Client(object):
             return resp.json()
         else:
             return {'success':False,'status_code':resp.status_code}
-            
+
+    # TODO: DEPRECATE
     def download_apply_model_results(self,model_id,process_id,wait=False,wait_interval=1.,output_path=None):
         """Fetch results or progress report for a model execution.
 
@@ -1209,13 +1278,55 @@ class Client(object):
             until the process is finished, and then return the result.
             If False, the client may immediately return a report
             that expresses the progress.
+        wait_interval : float
+            Interval to wait between status checks.
+
+        Returns
+        -------
+        resp : dict
+            Dict containing progress report, results, or error report
+        """
+        res = self.download_process_results(
+            process_id,
+            wait=wait,
+            wait_interval=wait_interval,
+            make_dataframe=True,
+            output_path=output_path
+        )
+        # COMPATIBILITY PATCH
+        res['df'] = res.pop('data')
+        return res
+
+    def download_process_results(self,process_id,wait=False,wait_interval=1.,make_dataframe=False,output_path=''):
+        """Fetch results or progress report for any process by process id.
+
+        Parameters
+        ----------
+        process_id : int
+            Integer id, as assigned to the process when it was started
+        wait : bool
+            If True, the client will retrieve the report repeatedly,
+            until the process is finished, and then return the result.
+            If False, the client may immediately return a report
+            that expresses the progress.
+        wait_interval : float
+            Interval to wait between status checks.
+        make_dataframe : bool
+            If True, attempt to read the file as a pandas.DataFrame.
+        output_path : str
+            If provided, and make_dataframe is True,
+            the dataframe is written to this path.
+
+        Returns
+        -------
+        resp : dict
+            Dict containing progress report, results, or error report
 
         Returns
         -------
         resp : dict
             Dict containing progress report, results, or error report
         """
-        # check the process
         procstat = self.session.get(
             self.service_url+'process_status',
             params={'process_id':process_id}
@@ -1229,23 +1340,19 @@ class Client(object):
                 ).json()
         if procstat['status'] == 'FINISHED':
             res = self.session.get(
-                self.service_url+'model_file',
-                params={
-                    'model_id':model_id,
-                    'file_tag':'RESULTS'+str(process_id),
-                    'file_ext':'.csv'
-                }
+                self.service_url+'download_file',
+                json={'file_tag':'RESULTS_'+str(process_id)}
             )
-            df = pd.read_csv(BytesIO(res._content),index_col='id')
-            if output_path:
-                df.to_csv(output_path)
-            return {'success':True,'data':res._content,'df':df}
+            data = res._content
+            if make_dataframe:
+                data = pd.read_csv(BytesIO(res._content),index_col='id')
+                if output_path:
+                    data.to_csv(output_path)
+            return {'success':True,'data':data}
         else:
             return procstat
 
 
-    # DESIGN PIPELINE
-
     def configure_design(self,design_id,scalar_columns=[],substance_columns=[],model_output_columns=[]):
         """Perform design configuration: step 1 of the design pipeline.
 
@@ -1650,13 +1757,13 @@ class Client(object):
         else:
             return {'success':False,'status_code':resp.status_code}
 
-    def edit_substance_set(self,name,names_to_add=[],names_to_remove=[]):
+    def edit_substance_set(self,set_id,names_to_add=[],names_to_remove=[]):
         """Update an existing substance set.
 
         Parameters
         ----------
-        name : str
-            Name of the substance set to be updated.
+        set_id : int 
+            Integer id of the substance set to be updated.
         names_to_add : list of str
             Substance names to add to the set. 
         names_to_remove : list of str
@@ -1670,7 +1777,7 @@ class Client(object):
         resp = self.session.post(
             self.service_url+'api/edit_substance_set', 
             json={
-                'name':name,
+                'set_id':set_id,
                 'names_to_add':names_to_add,
                 'names_to_remove':names_to_remove
             }
